Introduction
============

AlekSIS provides dashboard widgets for displaying feeds from external resources.
The following widgets are normal dashboard widgets and can be added and configured 
like described in :ref:`core-configure-dashboard-widgets`.
